# ik_constant_contact

Drupal 8 Module for Constant Contact using
their [API v3](https://v3.developer.constantcontact.com/).
Maintained and supported by
[Interactive Knowledge](https://interactiveknowledge.com).

## INTRODUCTION

This module uses
[v3](https://v3.developer.constantcontact.com/) of
the Constant Contact API.
It allows users to add an API key and secret generated by a
Constant Contact account in the settings.php
file (or via an admin UI). Then will allow users
to activate/enable a list and create a block
derivative for each list that is enabled.
It also provides an optional REST endpoint
to send signups to the CC API for enabled lists.

For a full description of the module, visit the
[project page](https://www.drupal.org/project/ik_constant_contact).

To submit bug reports and feature suggestions, or track changes
visit the [project issue page](https://www.drupal.org/project/issues/ik_constant_contact).

## REQUIREMENTS

This module requires the following modules enabled in Drupal Core:

* Block
* REST (if wanting to use the provided REST endpoint)
* Datetime (if using custom date fields)
* Webform (if wanting to send webform submissions to a enabled list)

This module also requires a
[Constant Contact](https://www.constantcontact.com) account
as well as an app created on the
[developer portal](https://v3.developer.constantcontact.com/login/index.html).

## INSTALLATION

* Install as you would normally install a contributed Drupal module.
[Visit Drupal's documentation for further information](https://www.drupal.org/documentation/install/modules-themes/modules-7).
* Detailed instructions on how to install and configure this module can be found [here](https://interactiveknowledge.com/insights/how-use-drupal-constant-contact-module)

## CONFIGURATION

* Configure the user permissions in Administration » People » Permissions
* Create an app on Constant Contact's
[developer portal](https://v3.developer.constantcontact.com/login/index.html).
* Copy the API Key provided, add the key to your settings.php file.
* Generate a secret in the developer portal,
copy it into your settings.php file.
* Your settings.php entry should look like this:

```php
$settings['ik_constant_contact'] = [
  'client_id' => 'your-api-key-goes-here',
  'client_secret' => 'your-client-secret-goes-here'
];
```

* If you prefer to use the UI, you can add these values to the admin UI
form located at `admin/config/services/ik-constant-contact`. Click save.
* Click the Authorize button to authorize your account (you may need to log
into Constsant Contact again) to generate tokens.
* Once tokens are generated, go to
`admin/config/services/ik-constant-contact/lists`
to enable the lists you'd like to place as blocks on your site or use as a
REST endpoint.

## WEBFORM HANDLER CONFIGURATION

* Go to Webforms list page (admin/structure/webform) and click "Edit" on
the desired Webform.
* Click Emails/Handlers secondary tab and then click on "Add handler" button.
* Click on "Add handler" button on "Constant Contact" row.
* Fill in the form. You should have at least one list in your Constant Contact
account, at least one list enabled in your Constant Contact Module settings
(/admin/config/services/ik-constant-contact/lists), and at least one Email
field in your Webform.
* If you want to map extra fields, you'll likely need to reference [Constant
Contact API documentation](https://v3.developer.constantcontact.com/api_guide/contacts_create.html#PHP2) to discover the field keys.
